SpotCheckState class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SpotCheckState
Constructors
Properties
- afterDelay → RxInt
-
final
-
appearance
→ RxMap<
String, dynamic> -
final
- avatarEnabled → RxBool
-
final
- avatarUrl → RxString
-
final
-
chatController
→ Rx<
WebViewController?> -
final
- chatUrl → RxString
-
final
-
classicController
→ Rx<
WebViewController?> -
final
- classicUrl → RxString
-
final
-
closeButtonStyle
→ RxMap<
String, dynamic> -
final
- currentKeyboardHeight → RxDouble
-
final
- currentQuestionHeight → RxInt
-
final
- customEventsSpotChecks → RxList
-
final
-
customProperties
→ Map<
String, dynamic> -
final
- domainName → String
-
final
- filteredSpotChecks → RxList
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBannerImageOn → RxBool
-
final
- isChat → RxBool
-
final
- isChatLoading → RxBool
-
final
- isClassicLoading → RxBool
-
final
- isCloseButtonEnabled → RxBool
-
final
- isFirstQuestion → RxBool
-
final
- isFullScreenMode → RxBool
-
final
- isInit → RxBool
-
final
- isInjected → RxBool
-
final
- isMounted → RxBool
-
final
- isRtl → RxBool
-
final
- isSpotCheckButton → RxBool
-
final
- isSpotCheckOpen → RxBool
-
final
- isSurveyLoaded → RxBool
-
final
- isValid → RxBool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxHeight → RxDouble
-
final
- position → RxString
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenHeight ↔ double
-
getter/setter pair
- screenName → RxString
-
final
- screenWidth ↔ double
-
getter/setter pair
- showSurveyContent → RxBool
-
final
-
spotCheckButtonConfig
→ RxMap<
String, dynamic> -
final
- spotcheckContactID → RxInt
-
final
- spotcheckID → RxInt
-
final
- spotCheckListener → SsSpotcheckListener?
-
final
- spotChecksMode → RxString
-
final
- spotCheckType → RxString
-
final
- spotcheckURL → RxString
-
final
- targetToken → String
-
final
- textPosition → RxDouble
-
final
- traceId → RxString
-
final
- triggerToken → RxString
-
final
-
userDetails
→ Map<
String, dynamic> -
final
-
variables
→ Map<
String, dynamic> -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
closeSpotCheck(
) → void -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
end(
{}) → void -
getUserAgent(
) → Future< String> -
initializeWidget(
String domainName, String targetToken) → Future< void> -
isChatSurvey(
String? type) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performSpotcheckBootstrap(
) → Future< void> -
sendTrackEventRequest(
String screen, Map< String, dynamic> event) → Future<Map< String, dynamic> > -
sendTrackScreenRequest(
String screen) → Future< Map< String, dynamic> > -
setAppearance(
Map< String, dynamic> responseJson, String screen) → void -
start(
) → void -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited