SpotCheckButtonConfig class
Constructors
- SpotCheckButtonConfig({required String type, String? position, String? buttonSize = 'medium', String? icon, String? generatedIcon, String? backgroundColor = '#4A9CA6', String? cornerRadius = 'sharp', String? textColor = '#FFFFFF', String? buttonText})
-
SpotCheckButtonConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- backgroundColor → String?
-
final
-
final
-
final
- cornerRadius → String?
-
final
- generatedIcon → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
final
- position → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → String?
-
final
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited