SpotCheckButtonUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getBorderRadius(
String? cornerRadius, String buttonSize) → double -
getSizeValue(
String buttonSize) → double -
getSizeValueTextButton(
String buttonSize) → double -
getTextStyle(
String buttonSize) → TextStyle -
hexToColor(
String hex, {double opacity = 1.0}) → Color